@@ -22,9 +22,9 @@ sub new {
 sub _init {
     my $self = shift;
     $self->{max_kids} //= 4;
-    $self->{ipc} //= 0; # ipc off by default
-    $self->{non_blocking} = 1;        
-}                          
+    $self->{ipc} //= 0;
+    $self->{non_blocking} //= 1;
+}
 
 
 sub max_kids {
@@ -38,7 +38,7 @@ sub non_blocking {
     my ($self, $n) = @_;
     $n // return $self->{non_blocking};
     $self->{non_blocking} = $n;
-} 
+}
 
 
 sub ipc {
@@ -67,7 +67,7 @@ sub fmap {
                 }
             }
         }
-        
+
         run_fork {  # processes fork here
             parent {
                 my $kid = shift;
@@ -76,6 +76,8 @@ sub fmap {
                     $pipe->reader();
                     if ($non_blocking) {
                         $pipe->blocking(0);
+                    } else {
+                        $pipe->blocking(1);
                     }
                     while(<$pipe>) {
                         push @rs, $_;
@@ -96,7 +98,7 @@ sub fmap {
             }
         };
     }
-    
+
     1 while (wait() != -1);  # wait for the stragglers to finish
     return @rs;
 }
@@ -108,64 +110,24 @@ sub fmap {
 __END__
 =head1 NAME
 
-Proc::Forkmap - map with forking and IPC
+Proc::Forkmap - map with forking
 
 =head1 SYNOPSIS
 
-EXAMPLES:
-    
-    sub foo {
-        my ($x,$n) = (shift,1);
-        $n *= $_ for (@$x);
-        say $n;
-    }
-    
-    @x = ([1..99],[100..199],[200..299]);
-    my $p = Proc::Forkmap->new;
-    $p->fmap(\&foo,@x);
-    
-    or,
-    
-    package Foo;
-    
-    sub new { return bless {}, shift};
-    sub bar { #do heavy calc stuff and max a CPU };
-    
-    package main;
-    
-    my $foo = Foo->new;
-    my @rs = Proc::Forkmap->new(max_kids => 4, ipc=> 1)->fmap(
-        sub { $foo->bar(@_) }, @x,
-    );
-    
-    or,
-    
-    my @rs = $p->fmap(sub { $_[0] ** $_[0] }, @x);
-    
-    or,
-    
-    #get stuff from the intertubes
-    
-    sub bar {
-       my $t = shift;
-       my $s = Stock::Price->new;
-       ... get historical stock prices ...
-       ... do some analysis ...
-       baz($t,$sell_price);
-    }
-    
-    #then save stuff to a data store
-    
-    sub baz {
-       my ($t,$price) = @_;
-       my $conn = MongoDB::Connection->new;
-       my $bayes = $conn->stock->bayes;
-       $bayes->insert({symbol => $t, price => $price});
-       $conn->disconnect;
-    }
-    
-    my $p = Proc::Forkmap->new(max_kids => 4);
-    $p->fmap(\&bar,qw/rht goog ^ixic ^dji yhoo aapl/);
+EXAMPLE:
+
+  use Proc::Forkmap;
+
+  sub foo {
+    my $x = shift;
+    my $t = sprintf("%1.0f", $x + 1);
+    sleep $t;
+    print "slept $t seconds\n";
+  }
+
+  my @x = (rand(), rand(), rand());
+  my $p = Proc::Forkmap->new;
+  $p->fmap(\&foo, @x);
 
 =head1 DESCRIPTION
 
@@ -175,7 +137,7 @@ This module supplies an easy to use map method that provides built-in forking an
 
 =head2 new
 
-    my $p = Proc::Forkmap->new(max_kids => 4, ipc => 1);
+    my $p = Proc::Forkmap->new(max_kids => 4)
 
 =over 4
 
@@ -189,7 +151,7 @@ Set IPC on/off state. IPC is off by default.
 
 =item B<non_blocking>
 
-Defaults to true. If IPC is on and non_blocking == 1, then $pipe->blocking(0).
+Defaults to 1, and falsy to block.
 
 =back
 
@@ -209,16 +171,13 @@ max_kids setter/getter.
 
     $p->non_blocking(1)
 
-If IPC is on, then set IO::Pipe blocking state.
+If IPC is on, then set IO::Handle blocking state. This might be useful for conditional parallelism.
 
 =head2 fmap
 
-    my @rs = $p->fmap(\&foo,@x);
+    $p->fmap(\&foo, @x);
 
-This method takes a coderef and an array. If IPC is turned on, it will return,
-via IO::Pipe, a result set. Otherwise, it will continue on its merry way until
-either an error occurs that prevents a fork or all the subprocesses complete
-their tasks.
+This method takes a coderef and an array. If IPC is blocking, then it will return a result set. Otherwise, it will continue, waiting for child processes to complete their tasks.
 
 =head1 TODO
 
